@@ -6,6 +6,7 @@ use std::str;
 use tui::{
     style::{Color, Modifier, Style},
     symbols::bar::FULL,
+    symbols::line::DOUBLE_VERTICAL,
 };
 
 trait TaskWarriorBool {
@@ -62,7 +63,9 @@ pub struct Config {
     pub uda_mark_indicator: String,
     pub uda_unmark_indicator: String,
     pub uda_scrollbar_indicator: String,
+    pub uda_scrollbar_area: String,
     pub uda_style_report_scrollbar: Style,
+    pub uda_style_report_scrollbar_area: Style,
     pub uda_selection_bold: bool,
     pub uda_selection_italic: bool,
     pub uda_selection_dim: bool,
@@ -81,6 +84,7 @@ pub struct Config {
     pub uda_quick_tag_name: String,
     pub uda_task_report_prompt_on_delete: bool,
     pub uda_task_report_prompt_on_done: bool,
+    pub uda_task_report_date_time_vague_more_precise: bool,
     pub uda_context_menu_select_on_move: bool,
 }
 
@@ -118,6 +122,7 @@ impl Config {
         let uda_mark_indicator = Self::get_uda_mark_indicator(data);
         let uda_unmark_indicator = Self::get_uda_unmark_indicator(data);
         let uda_scrollbar_indicator = Self::get_uda_scrollbar_indicator(data);
+        let uda_scrollbar_area = Self::get_uda_scrollbar_area(data);
         let uda_selection_bold = Self::get_uda_selection_bold(data);
         let uda_selection_italic = Self::get_uda_selection_italic(data);
         let uda_selection_dim = Self::get_uda_selection_dim(data);
@@ -126,6 +131,7 @@ impl Config {
         let uda_calendar_months_per_row = Self::get_uda_months_per_row(data);
         let uda_style_report_selection = Self::get_uda_style("report.selection", data);
         let uda_style_report_scrollbar = Self::get_uda_style("report.scrollbar", data);
+        let uda_style_report_scrollbar_area = Self::get_uda_style("report.scrollbar.area", data);
         let uda_style_calendar_title = Self::get_uda_style("calendar.title", data);
         let uda_style_calendar_today = Self::get_uda_style("calendar.today", data);
         let uda_style_context_active = Self::get_uda_style("context.active", data);
@@ -137,6 +143,7 @@ impl Config {
         let uda_style_report_selection = uda_style_report_selection.unwrap_or_default();
         let uda_style_report_scrollbar =
             uda_style_report_scrollbar.unwrap_or_else(|| Style::default().fg(Color::Black));
+        let uda_style_report_scrollbar_area = uda_style_report_scrollbar_area.unwrap_or_default();
         let uda_style_calendar_title = uda_style_calendar_title.unwrap_or_default();
         let uda_style_calendar_today =
             uda_style_calendar_today.unwrap_or_else(|| Style::default().add_modifier(Modifier::BOLD));
@@ -149,6 +156,7 @@ impl Config {
         let uda_task_report_prompt_on_delete = Self::get_uda_task_report_prompt_on_delete(data);
         let uda_task_report_prompt_on_done = Self::get_uda_task_report_prompt_on_done(data);
         let uda_context_menu_select_on_move = Self::get_uda_context_menu_select_on_move(data);
+        let uda_task_report_date_time_vague_more_precise = Self::get_uda_task_report_date_time_vague_more_precise(data);
 
         Ok(Self {
             enabled,
@@ -175,6 +183,7 @@ impl Config {
             uda_mark_indicator,
             uda_unmark_indicator,
             uda_scrollbar_indicator,
+            uda_scrollbar_area,
             uda_selection_bold,
             uda_selection_italic,
             uda_selection_dim,
@@ -188,12 +197,14 @@ impl Config {
             uda_style_report_completion_pane,
             uda_style_report_completion_pane_highlight,
             uda_style_report_scrollbar,
+            uda_style_report_scrollbar_area,
             uda_shortcuts,
             uda_background_process,
             uda_background_process_period,
             uda_quick_tag_name,
             uda_task_report_prompt_on_delete,
             uda_task_report_prompt_on_done,
+            uda_task_report_date_time_vague_more_precise,
             uda_context_menu_select_on_move,
         })
     }
@@ -541,6 +552,13 @@ impl Config {
             .unwrap_or(true)
     }
 
+    fn get_uda_task_report_date_time_vague_more_precise(data: &str) -> bool {
+        Self::get_config("uda.taskwarrior-tui.task-report.date-time-vague-more-precise", data)
+            .unwrap_or_default()
+            .get_bool()
+            .unwrap_or(false)
+    }
+
     fn get_uda_task_report_prompt_on_done(data: &str) -> bool {
         Self::get_config("uda.taskwarrior-tui.task-report.prompt-on-done", data)
             .unwrap_or_default()
@@ -599,6 +617,20 @@ impl Config {
             ),
         }
     }
+
+    fn get_uda_scrollbar_area(data: &str) -> String {
+        let area = Self::get_config("uda.taskwarrior-tui.scrollbar.area", data);
+        match area {
+            None => DOUBLE_VERTICAL.to_string(),
+            Some(area) => format!(
+                "{}",
+                area.chars()
+                    .next()
+                    .unwrap_or_else(|| DOUBLE_VERTICAL.to_string().chars().next().unwrap())
+            ),
+        }
+    }
+
     fn get_uda_mark_highlight_indicator(data: &str) -> String {
         let indicator = Self::get_config("uda.taskwarrior-tui.mark-selection.indicator", data);
         match indicator {
